@@ -17,6 +17,7 @@ from pathlib import Path
 # deps
 import numpy
 import numpy as np
+from importlib.metadata import version
 
 # app
 from pgamit import pyRinexName
@@ -31,6 +32,12 @@ class UtilsException(Exception):
         return str(self.value)
 
 
+def add_version_argument(parser):
+    __version__ = version('pgamit')
+    parser.add_argument('-v', '--version', action='version', version=f'%(prog)s {__version__}')
+    return parser
+
+
 def cart2euler(x, y, z):
     alt = numpy.rad2deg(numpy.sqrt(x**2 + y**2 + z**2) * 1e-9 * 1e6)
     lat = numpy.rad2deg(numpy.arctan2(z, numpy.sqrt(x**2 + y**2)))
@@ -195,7 +202,8 @@ def _increment_filename(filename):
     #  2) a "counter" - the integer which is incremented
     #  3) an "extension" - the file extension
 
-    sessions = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9] + [chr(x) for x in range(ord('a'), ord('z')+1)]
+    sessions = ([0, 1, 2, 3, 4, 5, 6, 7, 8, 9] + [chr(x) for x in range(ord('a'), ord('x')+1)] +
+                [chr(x) for x in range(ord('A'), ord('X')+1)])
 
     path      = os.path.dirname(filename)
     filename  = os.path.basename(filename)
@@ -847,7 +855,7 @@ def struct_unpack(fs, data):
 # also returns a positive int (ints are bignums on python 3)
 def crc32(s):
     x = zlib_crc32(bytes(s, 'utf-8'))
-    return x - ((x & 0x80000000) <<1)
+    return x - ((x & 0x80000000) << 1)
 
 
 # Text files
